<?php

namespace App\Http\Controllers;

use App\Models\Topic;
use Illuminate\Http\Request;
use Inertia\Inertia;

class TopicController extends Controller
{
    public function index()
    {
        return Inertia::render('Admin/Topics')
            ->title('Topics');
    }

    public function create()
    {
        return Inertia::render('Admin/SaveTopic')
            ->title('Create Topic');
    }

    public function update(Request $request)
    {
        $topic = Topic::find($request->id);

        if (!$topic) {
            abort(404);
        }

        return Inertia::render('Admin/SaveTopic', [
            'topic' => $topic,
        ])
            ->title('Update topic');
    }

    public function save(Request $request)
    {
        $topic = new Topic();
        if ($request->topic_id) {
            $topic = Topic::find($request->topic_id);
        }
        $request->validate([
            'name' => 'required|max:80|unique:topics,name,' . $request->topic_id,
            'description' => 'nullable|max:255',
            'color' => 'required|max:255',
        ]);
        $topic->name = $request->name;
        $topic->description = $request->description;
        $topic->color = $request->color;
        if ($topic?->save()) {
            return back()->with('success', 'Saved');
        }
    }

    public function delete(Request $request)
    {
        if ($request->user()->role == 1) {
            $topic = Topic::find($request->topic_id);
            if ($topic?->delete()) {
                return back()->with('success', 'Deleted');
            }
        }

    }
    public function get(Request $request)
    {
        $data = Topic::query();

        if ($request->topic_id) {
            $data = Topic::find($request->topic_id);
        } else {
            if ($request->key) {
                // Perform a search on the 'Topic' model using the search method
                $data = $data->search($request->key);
            }
            $data = $data->paginate($request->perpage);
        }

        return response()->json($data);
    }

}
