<?php

namespace App\Models;

use App\Models\Like;
use App\Models\Topic;
use Illuminate\Database\Eloquent\Concerns\HasUlids;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Laravel\Scout\Searchable;

class Post extends Model
{
    use HasFactory, HasUlids, Searchable;

    public function topic()
    {
        return $this->belongsTo(Topic::class, 'topic_id');
    }

    public function toSearchableArray()
    {
        return [
            'title' => $this->title,
            'content' => $this->content,
        ];
    }

    public function likes()
    {
        // Assuming you have a 'likes' relationship on the Post model
        return $this->hasMany(Like::class);
    }

    public function comments()
    {
        // Assuming you have a 'likes' relationship on the Post model
        return $this->hasMany(Comment::class);
    }

    // Eager load the likes count
    public function scopeWithLikesCount($query)
    {
        return $query->withCount('likes');
    }

}
