import { dateFormat } from "@/Libs/Common";
import { marked } from "marked";
import { useRef, useState } from "react";
import CommentEditor from "./CommentEditor";
import { router } from "@inertiajs/react";
// CommentEditor({ post, parent, onSave, onClose })
export default function CommentCard({ data, parent, auth, slot }) {
    function scrollToParent(id) {
        const el = document.getElementById(id);
        el.scrollIntoView({
            behavior: "smooth",
            block: "center",
            inline: "nearest",
        });
        el.style.backgroundColor = "#f8f8f8";
        setTimeout(() => {
            el.style.backgroundColor = "transparent";
        }, 1000);
    }
    const [showEditor, setShowEditor] = useState(false);
    const [showDeleteConfim, setShowDeleteConfim] = useState(false);
    const [showMenu, setShowMenu] = useState(false);
    const hash = window.location.hash;

    return (
        <div
            className={
                "flex flex-col gap-4 p-3" +
                (hash && hash == "#" + data.id ? " border-black border-2" : "")
            }
            id={data.id}
        >
            {showDeleteConfim ? (
                <>
                    <div>Delete this comment?</div>
                    <div className="flex justify-center items-center gap-2 ml-auto">
                        <button
                            className="flex border px-3 py-1 rounded-md border-red-500 justify-center items-center gap-2 text-red-500"
                            onClick={() => {
                                router.post(
                                    route("deleteComment"),
                                    {
                                        comment_id: data.id,
                                    },
                                    {
                                        preserveScroll: true,
                                        preserveState: true,
                                    }
                                );
                            }}
                        >
                            Delete
                        </button>
                        <button onClick={() => setShowDeleteConfim(false)}>
                            Cancel
                        </button>
                    </div>
                </>
            ) : showEditor ? (
                <>
                    <CommentEditor
                        title="Edit"
                        post={data}
                        markdown={data.text}
                        comment_id={data.id}
                        onSave={() => setShowEditor(false)}
                        onClose={() => setShowEditor(false)}
                    />
                </>
            ) : (
                <div className="grid grid-cols-[50px_auto]">
                    <div>
                        <img
                            src={data.user.avatar}
                            className="rounded-full h-8 w-8 bg-slate-100"
                        />
                    </div>
                    <div>
                        <div className="flex items-center text-sm gap-2 relative">
                            <span className="font-semibold">
                                {data.user.name}
                            </span>
                            &bull;
                            <span className="text-gray-500">
                                {dateFormat(data.created_at)}
                            </span>
                            {data.edited ? (
                                <span className="text-gray-500">
                                    &bull; Edited{" "}
                                </span>
                            ) : (
                                ""
                            )}
                            <button
                                onClick={() => {
                                    setShowMenu((pre) => !pre);
                                }}
                                className="ml-auto rounded-md"
                                id="commentCloseMenu"
                            >
                                {showMenu ? (
                                    <svg
                                        xmlns="http://www.w3.org/2000/svg"
                                        fill="none"
                                        viewBox="0 0 24 24"
                                        strokeWidth={1.5}
                                        stroke="currentColor"
                                        className="w-4 h-4"
                                    >
                                        <path
                                            strokeLinecap="round"
                                            strokeLinejoin="round"
                                            d="M6 18L18 6M6 6l12 12"
                                        />
                                    </svg>
                                ) : (
                                    <>&#8942;</>
                                )}
                            </button>
                            {showMenu && (
                                <div
                                    tabIndex="-1"
                                    focus="1"
                                    className="focus:border-red-600 flex flex-col gap-4 rounded-md absolute top-7 z-10 right-0 p-3 border bg-white dark:bg-gray-800"
                                >
                                    {auth.user &&
                                    (auth.user.id == data.user.id ||
                                        auth.user.role == 1) ? (
                                        <>
                                            <button
                                                className="text-left text-red-500"
                                                onClick={() =>
                                                    setShowDeleteConfim(true)
                                                }
                                            >
                                                Delete
                                            </button>
                                            <button
                                                className="text-left"
                                                onClick={() =>
                                                    setShowEditor(true)
                                                }
                                            >
                                                Edit
                                            </button>
                                        </>
                                    ) : (
                                        ""
                                    )}
                                    <button
                                        className="text-left"
                                        onClick={(e) => {
                                            e.target.innerHTML = "Reporting...";
                                            setTimeout(() => {
                                                e.target.innerHTML = "Reported";
                                                e.target.disabled = true;
                                            }, 500);
                                        }}
                                    >
                                        Report
                                    </button>
                                </div>
                            )}
                        </div>

                        {parent ? (
                            <a
                                className="text-blue-400 text-sm cursor-pointer"
                                onClick={() => scrollToParent(parent.id)}
                            >
                                @{parent.user.name}
                            </a>
                        ) : (
                            ""
                        )}
                        <div
                            dangerouslySetInnerHTML={{
                                __html: marked.parse(data.text),
                            }}
                        ></div>

                        {slot}
                    </div>
                </div>
            )}
        </div>
    );
}
