import {
    linkPlugin,
    linkDialogPlugin,
    CreateLink,
    MDXEditor,
    toolbarPlugin,
    BoldItalicUnderlineToggles,
    UndoRedo,
} from "@mdxeditor/editor";
import PrimaryButton from "@/Components/PrimaryButton";
import { Suspense, useState } from "react";
import { router } from "@inertiajs/react";
import SecondaryButton from "./SecondaryButton";

export default function CommentEditor({
    post,
    parent,
    onSave,
    onClose,
    markdown = "",
    comment_id,
    title,
}) {
    const [commentText, SetCommentText] = useState("");
    return (
        <>
            <div className="font-medium mb-2">{title}</div>
            <Suspense fallback={"Loading..."}>
                <MDXEditor
                    className="border rounded-md"
                    markdown={markdown}
                    onChange={(e) => SetCommentText(e)}
                    plugins={[
                        toolbarPlugin({
                            toolbarContents: () => (
                                <>
                                    <UndoRedo />
                                    <BoldItalicUnderlineToggles />
                                    <CreateLink />
                                </>
                            ),
                        }),
                        linkPlugin(),
                        linkDialogPlugin(),
                    ]}
                />
            </Suspense>
            <div className="flex items-center gap-3 mt-3">
                <PrimaryButton
                    onClick={() => {
                        if (!commentText.length) return;
                        router.post(
                            route("comment"),
                            {
                                post_id: post.id,
                                text: commentText,
                                parent_id: parent ? parent.id : null,
                                comment_id: comment_id ? comment_id : null,
                            },
                            {
                                preserveState: true,
                                preserveScroll: true,
                                onSuccess: (page) => (onSave ? onSave() : null),
                            }
                        );
                    }}
                >
                    Save
                </PrimaryButton>
                {onClose ? (
                    <SecondaryButton
                        onClick={() => {
                            onClose();
                        }}
                    >
                        Close
                    </SecondaryButton>
                ) : (
                    ""
                )}
            </div>
        </>
    );
}
