import React, { useState } from "react";
import CommentCard from "./CommentCard";
import CommentEditor from "./CommentEditor";

import { countNestedReplies } from "@/Libs/Common";

const Comment = ({
    comment,
    depth = 0,
    post,
    parent,
    auth,
    showreplies = false,
}) => {
    const [showReplies, setShowReplies] = useState(showreplies);
    const [showEditor, setShowEditor] = useState(false);
    const nestedRepliesCount = countNestedReplies(comment);

    const marginLeft = depth < 3 ? "50px" : "0px";

    function onSave() {
        setShowReplies(true);
        setShowEditor(false);
    }
    function onClose() {
        setShowEditor(false);
        if (!comment.replies.length) setShowReplies((pre) => !pre);
    }

    return (
        <div className={depth > 2 ? "" : "  "}>
            <CommentCard
                data={comment}
                parent={parent}
                auth={auth}
                slot={
                    <>
                        <button
                            className=" uplink mt-5 -ml-1"
                            onClick={() => {
                                setShowEditor(true);
                            }}
                        >
                            Reply
                        </button>

                        {showEditor ? (
                            <CommentEditor
                                title={"Replying to " + comment.user.name}
                                post={post}
                                parent={comment}
                                onSave={onSave}
                                onClose={onClose}
                                auth={auth}
                                className="mt-5"
                            />
                        ) : (
                            ""
                        )}

                        {comment.replies.length ? (
                            <button
                                className="uplink mt-5 w-full bg-slate-100 p-1 flex items-center gap-1 justify-center"
                                onClick={() => setShowReplies((pre) => !pre)}
                            >
                                {(showReplies ? "Hide " : "View ") +
                                    nestedRepliesCount +
                                    (nestedRepliesCount > 1
                                        ? "  replies"
                                        : "reply")}

                                <svg
                                    xmlns="http://www.w3.org/2000/svg"
                                    fill="none"
                                    viewBox="0 0 24 24"
                                    strokeWidth={1.5}
                                    stroke="currentColor"
                                    className={
                                        "w-4 h-4" +
                                        " " +
                                        (showReplies ? "rotate-180" : "")
                                    }
                                >
                                    <path
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                        d="M19.5 8.25l-7.5 7.5-7.5-7.5"
                                    />
                                </svg>
                            </button>
                        ) : (
                            ""
                        )}
                    </>
                }
            />

            {showReplies && comment.replies ? (
                <div style={{ marginLeft }}>
                    {comment.replies.map((reply) => (
                        <Comment
                            key={reply.id}
                            comment={reply}
                            depth={depth + 1}
                            post={post}
                            parent={comment}
                            auth={auth}
                            showreplies={showreplies}
                        />
                    ))}
                </div>
            ) : (
                ""
            )}
        </div>
    );
};

export const CommentsList = ({ comments, post, auth, showreplies }) => {
    return (
        <div>
            {comments.map((comment) => (
                <Comment
                    key={comment.id}
                    comment={comment}
                    post={post}
                    auth={auth}
                    showreplies={showreplies}
                />
            ))}
        </div>
    );
};
