import { useState } from "react";
import React from "react";
import ApplicationLogo from "@/Components/ApplicationLogo";
import Dropdown from "@/Components/Dropdown";
import ResponsiveNavLink from "@/Components/ResponsiveNavLink";
import { Link } from "@inertiajs/react";
import NavLink from "@/Components/NavLink";

const AdminNavLinks = [
    {
        label: "Dashboard",
        route: "admin.dashboard",
        dropdown: false,
    },
    {
        label: "Posts",
        dropdown: (
            <>
                <Dropdown.Link href={route("admin.posts.create")}>
                    Create
                </Dropdown.Link>
                <Dropdown.Link href={route("admin.posts")} as="button">
                    All
                </Dropdown.Link>
            </>
        ),
    },
    {
        label: "Topics",
        dropdown: (
            <>
                <Dropdown.Link href={route("admin.topics.create")}>
                    Create
                </Dropdown.Link>
                <Dropdown.Link href={route("admin.topics")} as="button">
                    All
                </Dropdown.Link>
            </>
        ),
    },
    {
        label: "Projects",
        dropdown: (
            <>
                <Dropdown.Link href={route("admin.projects.create")}>
                    Create
                </Dropdown.Link>
                <Dropdown.Link href={route("admin.projects")} as="button">
                    All
                </Dropdown.Link>
            </>
        ),
    },
    {
        label: "Users",
        route: "admin.users",
        dropdown: false,
    },
    {
        label: "Notifications",
        route: "notifications.send",
    },
    {
        label: "Uploads",
        route: "uploads",
        dropdown: false,
    },
];

export default function Authenticated({ user, header, children }) {
    const [showingNavigationDropdown, setShowingNavigationDropdown] =
        useState(false);

    return (
        <div className="min-h-screen bg-gray-100 dark:bg-gray-900">
            <nav className="bg-white dark:bg-gray-800 border-b border-gray-100 dark:border-gray-700">
                <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
                    <div className="flex justify-between h-16">
                        <div className="flex">
                            <div className="shrink-0 flex items-center">
                                <Link href="/">
                                    <ApplicationLogo className="block h-9 w-auto fill-current text-gray-800 dark:text-gray-200" />
                                </Link>
                            </div>

                            <div className="hidden space-x-8 sm:-my-px sm:ml-10 sm:flex">
                                {AdminNavLinks.map((o, i) => {
                                    return (
                                        <React.Fragment key={i}>
                                            {o.dropdown ? (
                                                <Dropdown className="inline-flex items-center ">
                                                    <Dropdown.Trigger>
                                                        {o.label}
                                                    </Dropdown.Trigger>

                                                    <Dropdown.Content width="100px">
                                                        {o.dropdown}
                                                    </Dropdown.Content>
                                                </Dropdown>
                                            ) : (
                                                <NavLink
                                                    key={i}
                                                    href={route(o.route)}
                                                    active={route().current(
                                                        o.route
                                                    )}
                                                >
                                                    {o.label}
                                                </NavLink>
                                            )}
                                        </React.Fragment>
                                    );
                                })}
                            </div>
                        </div>

                        <div className="hidden sm:flex sm:items-center sm:ml-6">
                            <div className="ml-3 relative">
                                <Dropdown>
                                    <Dropdown.Trigger>
                                        {user.name}
                                    </Dropdown.Trigger>

                                    <Dropdown.Content>
                                        <Dropdown.Link
                                            href={route("profile.edit")}
                                        >
                                            Profile
                                        </Dropdown.Link>
                                        <Dropdown.Link
                                            href={route("logout")}
                                            method="post"
                                            as="button"
                                        >
                                            Log Out
                                        </Dropdown.Link>
                                    </Dropdown.Content>
                                </Dropdown>
                            </div>
                        </div>

                        <div className="-mr-2 flex items-center sm:hidden">
                            <button
                                onClick={() =>
                                    setShowingNavigationDropdown(
                                        (previousState) => !previousState
                                    )
                                }
                                className="inline-flex items-center justify-center p-2 rounded-md text-gray-400 dark:text-gray-500 hover:text-gray-500 dark:hover:text-gray-400 hover:bg-gray-100 dark:hover:bg-gray-900 focus:outline-none focus:bg-gray-100 dark:focus:bg-gray-900 focus:text-gray-500 dark:focus:text-gray-400 transition duration-150 ease-in-out"
                            >
                                <svg
                                    className="h-6 w-6"
                                    stroke="currentColor"
                                    fill="none"
                                    viewBox="0 0 24 24"
                                >
                                    <path
                                        className={
                                            !showingNavigationDropdown
                                                ? "inline-flex"
                                                : "hidden"
                                        }
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                        strokeWidth="2"
                                        d="M4 6h16M4 12h16M4 18h16"
                                    />
                                    <path
                                        className={
                                            showingNavigationDropdown
                                                ? "inline-flex"
                                                : "hidden"
                                        }
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                        strokeWidth="2"
                                        d="M6 18L18 6M6 6l12 12"
                                    />
                                </svg>
                            </button>
                        </div>
                    </div>
                </div>

                <div
                    className={
                        (showingNavigationDropdown ? "block" : "hidden") +
                        " sm:hidden"
                    }
                >
                    <div className="pt-2 pb-3 space-y-1">
                        {AdminNavLinks.map((o, i) => {
                            return (
                                <React.Fragment key={i}>
                                    {o.dropdown ? (
                                        <Dropdown className="w-full flex items-start  py-2 border-l-4">
                                            <Dropdown.Trigger className="!w-full">
                                                {o.label}
                                            </Dropdown.Trigger>

                                            <Dropdown.Content>
                                                {o.dropdown}
                                            </Dropdown.Content>
                                        </Dropdown>
                                    ) : (
                                        <ResponsiveNavLink
                                            key={i}
                                            href={route(o.route)}
                                            active={route().current(o.route)}
                                        >
                                            {o.label}
                                        </ResponsiveNavLink>
                                    )}
                                </React.Fragment>
                            );
                        })}
                    </div>

                    <div className="pt-4 pb-1 border-t border-gray-200 dark:border-gray-600">
                        <div className="px-4">
                            <div className="font-medium text-base text-gray-800 dark:text-gray-200">
                                {user.name}
                            </div>
                            <div className="font-medium text-sm text-gray-500">
                                {user.email}
                            </div>
                        </div>

                        <div className="mt-3 space-y-1">
                            <ResponsiveNavLink href={route("profile.edit")}>
                                Profile
                            </ResponsiveNavLink>
                            <ResponsiveNavLink
                                method="post"
                                href={route("logout")}
                                as="button"
                            >
                                Log Out
                            </ResponsiveNavLink>
                        </div>
                    </div>
                </div>
            </nav>

            {header && (
                <header className="bg-white dark:bg-gray-800 shadow">
                    <div className="max-w-7xl mx-auto py-6 px-4 sm:px-6 lg:px-8">
                        {typeof header == "string" ? (
                            <h2 className="capitalize font-semibold text-xl text-gray-800 dark:text-gray-200 leading-tight">
                                {header}
                            </h2>
                        ) : (
                            header
                        )}
                    </div>
                </header>
            )}

            <main>
                <div className="py-12">
                    <div className="max-w-7xl mx-auto sm:px-6 lg:px-8">
                        <div className=" overflow-hidden  sm:rounded-lg">
                            <div className="p-6 text-gray-900 dark:text-gray-100">
                                {children}
                            </div>
                        </div>
                    </div>
                </div>
            </main>
        </div>
    );
}
