import InputError from "@/Components/InputError";
import InputLabel from "@/Components/InputLabel";
import PrimaryButton from "@/Components/PrimaryButton";
import Section from "@/Components/Section";
import TextInput from "@/Components/TextInput";
import Authenticated from "@/Layouts/AuthenticatedLayout";
import { isImageFile } from "@/Libs/Common";
import { router } from "@inertiajs/react";
import { useForm } from "@inertiajs/react";

export default function Media({ auth, files }) {
    const { data, setData, post, progress, errors } = useForm({
        file: null,
    });
    console.log(files);
    function submit(e) {
        e.preventDefault();
        post(route("upload-file"));
    }
    return (
        <Authenticated user={auth.user}>
            <Section>
                <form onSubmit={submit}>
                    {progress && (
                        <progress value={progress.percentage} max="100">
                            {progress.percentage}%
                        </progress>
                    )}
                    <div className="mt-4">
                        <InputLabel htmlFor="file" value="File" />

                        <TextInput
                            id="file"
                            type="file"
                            name="file"
                            onChange={(e) => setData("file", e.target.files[0])}
                            className="mt-1 block w-full border-2"
                            autoComplete="username"
                        />

                        <InputError
                            message={errors.file ? errors.file : false}
                            className="mt-2"
                        />
                    </div>

                    <PrimaryButton type="submit" className="mt-5">
                        Submit
                    </PrimaryButton>
                </form>

                <div className="md:columns-2 lg:columns-3 mt-5">
                    {files.map((file) => (
                        <div className="border flex gap-5 items-center p-3 break-inside-avoid-column">
                            <div>
                                {isImageFile(file) ? (
                                    <img
                                        src={"/storage/uploads/" + file}
                                        className="w-6 h-6"
                                    />
                                ) : (
                                    <svg
                                        xmlns="http://www.w3.org/2000/svg"
                                        fill="none"
                                        viewBox="0 0 24 24"
                                        strokeWidth={1.5}
                                        stroke="currentColor"
                                        className="w-6 h-6"
                                    >
                                        <path
                                            strokeLinecap="round"
                                            strokeLinejoin="round"
                                            d="M3.75 9.776c.112-.017.227-.026.344-.026h15.812c.117 0 .232.009.344.026m-16.5 0a2.25 2.25 0 00-1.883 2.542l.857 6a2.25 2.25 0 002.227 1.932H19.05a2.25 2.25 0 002.227-1.932l.857-6a2.25 2.25 0 00-1.883-2.542m-16.5 0V6A2.25 2.25 0 016 3.75h3.879a1.5 1.5 0 011.06.44l2.122 2.12a1.5 1.5 0 001.06.44H18A2.25 2.25 0 0120.25 9v.776"
                                        />
                                    </svg>
                                )}
                            </div>
                            <div>
                                <a
                                    href={"/storage/uploads/" + file}
                                    target="_blank"
                                >
                                    {file}
                                </a>
                            </div>
                            <button
                                type="button"
                                className="ml-auto"
                                onClick={() => {
                                    if (confirm("Are u sure")) {
                                        router.post(route("delete-file"), {
                                            filename: file,
                                        });
                                    }
                                }}
                            >
                                <svg
                                    xmlns="http://www.w3.org/2000/svg"
                                    fill="none"
                                    viewBox="0 0 24 24"
                                    strokeWidth={1.5}
                                    stroke="currentColor"
                                    className="w-6 h-6"
                                >
                                    <path
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                        d="M6 18L18 6M6 6l12 12"
                                    />
                                </svg>
                            </button>
                        </div>
                    ))}
                </div>
            </Section>
        </Authenticated>
    );
}
