import React, { useState } from "react";
import AuthenticatedLayout from "@/Layouts/AuthenticatedLayout";
import { Datatable, defaultSort } from "joydeep-react-datatable";
import Spinner from "@/Components/Spinner";
import { Link } from "@inertiajs/react";
import axios from "axios";
import Section from "@/Components/Section";

const columns = () => [
    {
        key: "name",
        label: "Name",
        sortable: true,
    },
    {
        key: "email",
        label: "Email",
        sortable: true,
    },
    {
        key: "role",
        label: "Role",
        sortable: true,
        value: (row) => (row.role == 1 ? "Admin" : !row.role ? "User" : null),
    },
    {
        key: "updated_at",
        label: "Updated at",
        sortable: true,
    },
];

export default function Users({ auth }) {
    const [json, setJson] = useState([]);
    const [data, setData] = useState(json);
    const [loading, setLoading] = useState(false);

    function sort(key, direction) {
        setData(defaultSort({ data, key: key, direction: direction }));
    }
    function getApiParams(data) {
        setLoading(true);
        axios
            .post("/api/users", data)
            .then((res) => {
                const data = res.data.data;
                setJson(data); // Update the json state
                setData(data); // Update the data state
            })
            .catch((error) => console.error(error))
            .finally(() => {
                setLoading(false);
            });
    }

    return (
        <AuthenticatedLayout user={auth.user} header="Users">
            <Section>
                <Datatable
                    columns={columns()}
                    data={data}
                    sort={sort}
                    getApiParams={getApiParams}
                    pagination={true}
                    loading={loading}
                    loader={<Spinner />}
                />
            </Section>
        </AuthenticatedLayout>
    );
}
