import Layout from "@/Layouts/Layout";
import { marked } from "marked";
import hljs from "highlight.js";
import { Link, router } from "@inertiajs/react";
import "@mdxeditor/editor/style.css";
import ToggleNotificationPermission from "@/Components/ToggleNotificationPermission";
import { CommentsList } from "@/Components/Comments";
import CommentEditor from "@/Components/CommentEditor";
import { useEffect, useState } from "react";
import "../../css/vs-2015.css";
import {
    calculateReadingTime,
    dateFormat,
    addCodeTagFeature,
} from "@/Libs/Common";

export default function Post({
    auth,
    post,
    comments,
    commentsCount,
    relatedPosts,
}) {
    const { title, content, topic, slug, likes, cover_image, created_at } =
        post;
    const [showComments, setShowComments] = useState(
        window.location.hash.length
    );
    const [showEditor, setShowEditor] = useState(false);
    const Liked = likes.filter((r) => r.user_id == auth.user?.id).length;
    useEffect(() => {
        hljs.configure({
            languages: [],
        });
        hljs.highlightAll();
        addCodeTagFeature(".markdown");
    }, []);
    return (
        <Layout user={auth.user} className="space-y-10">
            <header className="space-y-5 mt-10">
                {topic && (
                    <Link
                        href={"/?topic=" + topic.name}
                        className="uplink font-bold transition-all"
                    >
                        {topic.name}
                    </Link>
                )}
                <h1 className="capitalize font-extrabold text-4xl md:text-5xl ">
                    {title}
                </h1>

                <div className="md:flex items-center gap-3 text-sm">
                    <div className="flex gap-1 items-center text-slate-600 uppercase">
                        <svg
                            xmlns="http://www.w3.org/2000/svg"
                            fill="none"
                            viewBox="0 0 24 24"
                            strokeWidth={1.5}
                            stroke="currentColor"
                            className="w-5 h-5"
                        >
                            <path
                                strokeLinecap="round"
                                strokeLinejoin="round"
                                d="M12 6v6h4.5m4.5 0a9 9 0 11-18 0 9 9 0 0118 0z"
                            />
                        </svg>
                        {calculateReadingTime(content)} min
                        <div className="ml-3 ">{dateFormat(created_at)}</div>
                    </div>

                    <div className="ml-auto divide-x space-x-2 mt-5 md:mt-0">
                        <button
                            type="button"
                            onClick={(e) => {
                                if (auth.user) {
                                    return router.post(
                                        route("like"),
                                        {
                                            post_id: post.id,
                                        },
                                        {
                                            preserveState: false,
                                            preserveScroll: true,
                                        }
                                    );
                                }
                                router.visit("login");
                            }}
                            className={
                                "uplink " + (Liked ? "font-extrabold" : "")
                            }
                        >
                            {likes.length
                                ? likes.length +
                                  (likes.length > 1 ? "   likes" : "   like")
                                : "like"}
                        </button>

                        <button
                            type="button"
                            className="uplink "
                            onClick={() =>
                                document
                                    .getElementById("comments")
                                    .scrollIntoView({
                                        behavior: "smooth",
                                        block: "start",
                                        inline: "start",
                                    })
                            }
                        >
                            {commentsCount
                                ? commentsCount +
                                  (commentsCount > 1
                                      ? "  comments"
                                      : "  comment")
                                : "comment"}
                        </button>

                        <button
                            type="button"
                            className="uplink "
                            onClick={() => {
                                if (navigator.share) {
                                    navigator
                                        .share({
                                            title: document.title,
                                            // text: "Hello World",
                                            url: window.location.href,
                                        })
                                        .then(() =>
                                            console.log("Successful share")
                                        )
                                        .catch((error) =>
                                            console.log("Error sharing:", error)
                                        );
                                }
                            }}
                        >
                            Share
                        </button>
                    </div>
                </div>
            </header>
            {cover_image && (
                <img
                    src={"/storage/cover/" + cover_image}
                    alt=""
                    className="rounded-md "
                />
            )}
            <article
                className="mt-10 single-post-content markdown"
                dangerouslySetInnerHTML={{
                    __html: marked.parse(content),
                }}
            />
            <section className="space-y-5" id="comments">
                <div className="flex items-center  flex-wrap">
                    <h2 className="font-bold">
                        Comments{" "}
                        {commentsCount ? "( " + commentsCount + " )" : ""}
                    </h2>
                    {auth.user && !auth.user.notify ? (
                        <div className="flex gap-3 items-center ml-auto mt-5 text-sm md:mt-0">
                            Allow notification
                            <ToggleNotificationPermission auth={auth} />
                        </div>
                    ) : (
                        ""
                    )}
                </div>
                {auth.user ? (
                    showEditor ? (
                        <>
                            <CommentEditor
                                post={post}
                                onClose={() => setShowEditor((pre) => !pre)}
                                onSave={() => setShowComments(true)}
                            />
                        </>
                    ) : (
                        <div
                            className="bg-slate-50 border rounded px-3 py-2 cursor-pointer"
                            onClick={() => setShowEditor((pre) => !pre)}
                        >
                            Write a comment ...
                        </div>
                    )
                ) : (
                    <div className="uplink text-center">
                        <Link href={route("login")} className="text-blue-400">
                            Sigin
                        </Link>{" "}
                        to comment
                    </div>
                )}
                <div className="mt-5">
                    {showComments ? (
                        <CommentsList
                            comments={comments}
                            post={post}
                            auth={auth}
                            showreplies={window.location.hash.length}
                        />
                    ) : (
                        ""
                    )}

                    {comments.length ? (
                        <center>
                            <button
                                type="button"
                                onClick={() => setShowComments((pre) => !pre)}
                                className="uplink mt-5 flex items-center gap-1 justify-center"
                            >
                                {showComments
                                    ? " Hide Comments"
                                    : " Show all comments"}{" "}
                                ({commentsCount})
                                <svg
                                    xmlns="http://www.w3.org/2000/svg"
                                    fill="none"
                                    viewBox="0 0 24 24"
                                    strokeWidth={1.5}
                                    stroke="currentColor"
                                    className={
                                        "w-4 h-4" +
                                        " " +
                                        (showComments ? "rotate-180" : "")
                                    }
                                >
                                    <path
                                        strokeLinecap="round"
                                        strokeLinejoin="round"
                                        d="M19.5 8.25l-7.5 7.5-7.5-7.5"
                                    />
                                </svg>
                            </button>
                        </center>
                    ) : (
                        ""
                    )}
                </div>
            </section>
        </Layout>
    );
}
